NAME
Ixchel::Actions::xeno - Invokes xeno_build with the specified hash.
VERSION
Version 0.2.0
SYNOPSIS
use Data::Dumper;
my $results=$ixchel->action(action=>'xeno', opts=>{r=>'librenms/extends/smart' });
print Dumper($results);
FLAGS
--xb <file>
Read this YAML file to use for with xeno_build.
-r <repo item>
Uses the specified value to fetch 'https://raw.githubusercontent.com/LilithSec/xeno_build/main/$repo_item.yaml'.
-u <url>
Install use the file from URL.
RESULT HASH REF
.errors :: A array of errors encountered.
.status_text :: A string description of what was done and the results.
.ok :: Set to zero if any of the above errored.